@@ -2,7 +2,8 @@ plot.FAMD <- function (x, choix = c("ind","var","quanti","quali"), axes = c(1, 2
     lab.var = TRUE, lab.ind = TRUE, habillage = "none", col.lab = FALSE,
     col.hab = NULL, invisible = NULL, lim.cos2.var = 0., xlim = NULL,
     ylim = NULL, title = NULL, palette=NULL, autoLab = c("auto","yes","no"), new.plot = FALSE, 
-	select = NULL, unselect = 0.7, shadowtext=FALSE,...) {
+	select = NULL, unselect = 0.7, shadowtext=FALSE,
+	legend = list(bty = "y", x = "topleft"),...) {
 
 autoLab <- match.arg(autoLab,c("auto","yes","no"))
 if (autoLab=="yes") autoLab=TRUE
@@ -47,6 +48,7 @@ plot.MFA (x, axes = axes, choix = choix, lab.var = lab.var,
     lab.ind = lab.ind, lab.par = FALSE, habillage = habillage,
     col.hab = col.hab, invisible = invisible, lim.cos2.var = lim.cos2.var, 
     xlim = xlim, ylim = ylim, title = title, palette=palette, new.plot=new.plot,
-	select=select,unselect=unselect,autoLab=autoLab,shadowtext=shadowtext,...)
+	select=select,unselect=unselect,autoLab=autoLab,shadowtext=shadowtext,
+	legend=legend,...)
 } 
 }
